@@ -18,8 +18,16 @@ calc_mortality <- function(x, budswelling, hatch, mot = 0) {
   to <- max(get_time(starve))
 
   x <- subset_time(x, from, to)
+  time <- terra::time(x$tmean)
+
   x <- lapply(x, function(y) terra::ifel(starve, y, -999))
 
+  x <- lapply(x, function(y) {
+    terra::time(y) <- time
+  return(y)
+  }
+  )
+
   dd <- calc_degreedays(x, ts_start = from, ts_end = to, ldt = mot, method = "tsum")
 
   mortality_tab <- matrix(
